@@ -1,5 +1,5 @@
 package Git::Database::Backend::Git::Repository;
-$Git::Database::Backend::Git::Repository::VERSION = '0.002';
+$Git::Database::Backend::Git::Repository::VERSION = '0.003';
 use IO::Select;
 use Sub::Quote;
 
@@ -94,7 +94,7 @@ sub get_object_attributes {
     warn $bang if $bang;
 
     # object does not exist in the git object database
-    return if $parts[-1] eq 'missing';
+    return undef if $parts[-1] eq 'missing';
 
     # read the whole content in memory at once
     my $res = read $out, (my $content), $size;
@@ -205,7 +205,7 @@ Git::Database::Backend::Git::Repository - A Git::Database backend based on Git::
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
