@@ -1,6 +1,13 @@
 package Git::Database::Backend::Git::Sub;
-$Git::Database::Backend::Git::Sub::VERSION = '0.002';
-use Git::Sub;
+$Git::Database::Backend::Git::Sub::VERSION = '0.003';
+use Git::Sub qw(
+   cat_file
+   hash_object
+   rev_list
+   show_ref
+   update_ref
+   version
+);
 use Git::Version::Compare qw( ge_git );
 use File::pushd qw( pushd );
 
@@ -59,7 +66,7 @@ sub get_object_attributes {
     my ( $sha1, $kind, $size ) = my @parts = split / /, $meta;
 
     # object does not exist in the git object database
-    return if $parts[-1] eq 'missing';
+    return undef if $parts[-1] eq 'missing';
 
     return {
         kind       => $kind,
@@ -156,7 +163,7 @@ Git::Database::Backend::Git::Sub - A Git::Database backend based on Git::Sub
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
