@@ -1,5 +1,5 @@
 package Git::Database::Role::ObjectReader;
-$Git::Database::Role::ObjectReader::VERSION = '0.002';
+$Git::Database::Role::ObjectReader::VERSION = '0.003';
 use Git::Database::Object::Blob;
 use Git::Database::Object::Tree;
 use Git::Database::Object::Commit;
@@ -27,18 +27,12 @@ sub get_object_meta {
       : ( $digest, 'missing', undef );
 }
 
-my %kind2class = (
-    blob   => 'Git::Database::Object::Blob',
-    tree   => 'Git::Database::Object::Tree',
-    commit => 'Git::Database::Object::Commit',
-    tag    => 'Git::Database::Object::Tag',
-);
-
 sub get_object {
     my ( $self, $digest ) = @_;
     my $attr = $self->get_object_attributes($digest);
     return $attr
-      && $kind2class{ $attr->{kind} }->new( %$attr, backend => $self );
+      && "Git::Database::Object::\u$attr->{kind}"
+      ->new( %$attr, backend => $self );
 }
 
 1;
@@ -53,7 +47,7 @@ Git::Database::Role::ObjectReader - Abstract role for a Git backends that read o
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
